# This project is for  biomedical article extraction process with author and affiliation normalization

### How to use it

#### Project Skeleton
```sh
..\article_extraction\
│
├── .idea\
│   └── workspace.xml
│
├── article_extraction\
│   └── extraction.py
│
├── data_directory\
│
├── .gitignore
├── LICENSE
└── README.md

```
